@@ -9,6 +9,8 @@
 
 #include "book.h"
 
+class QModelIndex;
+
 /** Visual representation of a book. */
 class BookView: public QWebView
 {
@@ -24,7 +26,8 @@ public:
     void setLastBookmark();
 
 signals:
-    void chapterLoaded(int index);
+    void chapterLoadStart(int index);
+    void chapterLoadEnd(int index);
 
 public slots:
     void goPrevious();
